package Locale::CLDR::Ve::Any v0.25.0;
# This file auto generated
#	on Tue 22 Apr 12:55:28 am GMT

use v5.18;
use mro 'c3';

use Moose;

extends('Locale::CLDR::Ve');

no Moose;
__PACKAGE__->meta->make_immutable;
